import numpy as np
import matplotlib.pyplot as plt
plt.ion()
plt.close() 
plt.rcParams.update({'font.size': 14})

t0 = 0 #Initial time
t1 = 10 #Final time
t1 = 100
dt = (t1-t0)/100000 #Takes 100,000 intermediate steps, you can adjust this

#Parameters for Lotka-Volterra equation
k = 2
r = 1
a = 10
b = 5
make_extinct = True #Should we make small populations go extinct

#Initial conditions at t0 time
#W0 = 0.1 #Predator
#R0 = 0.1 #Prey

#W0 = 0.5 #Predator
#R0 = 0.1 #Prey

W0 = 5 #Predator
R0 = 0.1 #Prey

#Set up variables
t = np.arange(t0,t1,dt)
W = np.zeros_like(t)
R = np.zeros_like(t)
W[0] = W0
R[0] = R0


minR = R[0]
#Solve differential equations with Euler-Method
for i in range(len(t)-1):
    W[i+1] = W[i] + dt*(-r*W[i] + b*R[i]*W[i])
    R[i+1] = R[i] + dt*(k*R[i] - a*R[i]*W[i])
    minR = np.minimum(minR,R[i+1])

    #Make populations go extinct if less than one individual
    if make_extinct:
        if W[i+1] < 1/1000:
            W[i+1]=0
        if R[i+1] < 1/1000:
            R[i+1]=0


print('Minimum prey population = ',100*minR)
#Plot solutions
plt.xlabel('Time')
plt.ylabel('Population')
plt.plot(t,1000*R,label='Prey population')
plt.plot(t,1000*W,label='Predator population')
plt.legend(loc='upper left')
